import { createBrowseHistory, createBrowseRecord } from '@/core/libs/requests'
import { useUserStore } from '@/store'
import { storeToRefs } from 'pinia'
import dayjs from 'dayjs'
export enum AnalysisEventType {
  LaunchApp = 4,
  /**
   * 发布圈子
   */
  PublishCircle = 5,
  /**
   * 浏览页面
   */
  ViewPage = 6,
}
export const useAnalysis = (automatic: boolean, isApp = false) => {
  const userStore = useUserStore()
  const { userInfo, isLogined } = storeToRefs(userStore)
  const viewDuration = ref(0)
  const viewStartAt = ref<Date | null>(null);
  const option = ref<Record<string, any>>({})

  const report = async (type: AnalysisEventType, duration: number) => {
    if (!isLogined.value) return;

    try {
      await createBrowseRecord({
        stylistId: userInfo.value.userId,
        bizType: type,
        duration,
        ...option.value,
      });
    } catch (error) {
      console.error('Failed to report:', error);
    } finally {
      option.value = {};
    }
  };

  onLaunch(async () => {
    if (automatic) {
      if (isApp) {
        await report(AnalysisEventType.LaunchApp,0)
      }
    }
  })
  onLoad(() => {
    console.log('analysis')
  })
  onShow(() => {
    console.log('show')
    if (automatic) {
      viewStartAt.value = new Date()
      // if (isApp) {
      //
      // }
    }
  })
  onHide(async () => {
    if (automatic && viewStartAt.value) {
      const duration = dayjs().diff(viewStartAt.value, 'second');
      console.log(`本次使用时长：${duration} 秒`);
      await report(AnalysisEventType.ViewPage, duration);
    }
  });

  onUnload(async () => {
    // if (automatic) {
    //   await report(AnalysisEventType.ViewPage)
    // }
  })
  return { option, report }
}
